import { AES } from './aes';
import { SHA256 } from './sha256';
/**
 * FORTUNA random class
 */
export declare class Random {
    NUM_POOLS: number;
    RESEED_LIMIT: number;
    MILLISECONDS_PER_RESEED: number;
    gen: AES;
    genKey: Uint8Array;
    genCnt: Uint8Array;
    poolData: Array<SHA256>;
    poolEntropy: Array<number>;
    robin: {
        kbd: number;
        mouse: number;
        scroll: number;
        touch: number;
        motion: number;
        time: number;
        rnd: number;
        dom: number;
    };
    entropy_level: number;
    eventId: number;
    reseedCnt: number;
    lastReseed: number;
    active: boolean;
    timer: number;
    /**
     * ctor
     * @param {Number} numPools Number of pools used for entropy acquisition. Defaults to 32 pools, use 16 on limited entropy sources
     * @param {Uint8Array} entropy Optional array of any length with initial (true) random data
     */
    constructor(numPools?: number, entropy?: Uint8Array);
    /**
     * Stop the generator
     */
    stop(): void;
    /**
     * Return the actual generator entropy (number of available random bytes)
     * @return {Number} Number of available random bytes
     */
    getEntropy(): number;
    /**
     * Add external given entropy
     * @param {Uint8Array} entropy Random bytes to be added to the entropy pools
     */
    addEntropy(entropy: Uint8Array): void;
    private init(entropy?);
    /**
     * Reseed the generator with the given byte array
     */
    private reseed(seed);
    /**
     * Internal function to generates a number of (16 byte) blocks of random output
     * @param {Number} blocks Number of blocks to generate
     */
    private generateBlocks(blocks);
    /**
     * Internal function to get random data bytes
     */
    private pseudoRandomData(length);
    /**
     * Get random data bytes
     * @param {Number} length Number of bytes to generate
     * @return {Uint8Array} Byte array of crypto secure random values or undefined, if generator is not ready
     */
    get(length: number): Uint8Array;
    /**
     * Start the built-in entropy collectors
     */
    private startCollectors();
    /**
     * Stop the built-in entropy collectors
     */
    private stopCollectors();
    /**
     * In case of an event burst (eg. motion events), this executes the given fn once every threshold
     * @param {Function} fn Function to be throttled
     * @param {number} threshold Threshold in [ms]
     * @returns {Function} Resulting function
     */
    private throttle(fn, threshold, scope?);
    private addRandomEvent(data, pool_idx, entropy?);
    private collectorKeyboard(ev);
    private collectorMouse(ev);
    private collectorClick(ev);
    private collectorTouch(ev);
    private collectorScroll(ev);
    private collectorMotion(ev);
    private collectorTime();
    private collectorDom();
    private collectorCryptoRandom();
}
